@@ -32,14 +32,14 @@
 //! # use tryrun::prelude::*;
 //! Command::cargo_miri("test")
 //!     .args(&["-q", "--lib", "--target-dir=target/miri"])
-//!     .run_pass(OutputStr::stdout_only("tests/ui/cargo_miri_test.stdout"), normalize::noop());
+//!     .run_pass(OutputStr::stdout("tests/ui/cargo_miri_test.stdout"), normalize::noop());
 //! ```
 //!
 //! ### Test that `rustc -V` runs successfully and has expected stdout after normalization and empty stderr
 //! ```
 //! # use tryrun::prelude::*;
 //! Command::rustc().arg("-V").run_pass(
-//!    OutputStr::stdout_only("tests/ui/rustc_version.stdout"),
+//!    OutputStr::stdout("tests/ui/rustc_version.stdout"),
 //!    normalize::stdout(|output| {
 //!        output.truncate("rustc 1.".len());
 //!        output.push(b'\n');
@@ -52,7 +52,7 @@
 //! ```
 //! # use tryrun::prelude::*;
 //! Command::rustdoc().arg("-V").run_pass(
-//!    OutputStr::stdout_only("tests/ui/rustdoc_version.stdout"),
+//!    OutputStr::stdout("tests/ui/rustdoc_version.stdout"),
 //!    normalize::stdout(|output| {
 //!        output.truncate("rustdoc 1.".len());
 //!        output.push(b'\n');
@@ -65,7 +65,7 @@
 //! ```
 //! # use tryrun::prelude::*;
 //! Command::clippy().arg("-V").run_pass(
-//!     OutputStr::stdout_only("tests/ui/clippy_version.stdout"),
+//!     OutputStr::stdout("tests/ui/clippy_version.stdout"),
 //!     normalize::stdout(|output| {
 //!         output.truncate("clippy".len());
 //!         output.push(b'\n');
@@ -382,13 +382,13 @@ impl<StdOut, StdErr> Output<StdOut, StdErr> {
     /// ## Example
     /// ```
     /// # use tryrun::prelude::*;
-    /// const STDOUT_ONLY: OutputStr = OutputStr::stdout_only("foo/bar.stdout");
+    /// const STDOUT_ONLY: OutputStr = OutputStr::stdout("foo/bar.stdout");
     /// assert_eq!(STDOUT_ONLY.stdout.unwrap(), "foo/bar.stdout");
     /// assert!(STDOUT_ONLY.stderr.is_none());
     /// ```
     #[must_use]
     #[inline(always)]
-    pub const fn stdout_only(stdout: StdOut) -> Self {
+    pub const fn stdout(stdout: StdOut) -> Self {
         Self {
             stdout: Some(stdout),
             stderr: None,
@@ -400,13 +400,13 @@ impl<StdOut, StdErr> Output<StdOut, StdErr> {
     /// ## Example
     /// ```
     /// # use tryrun::prelude::*;
-    /// const STDERR_ONLY: OutputStr = OutputStr::stderr_only("foo/bar.stderr");
+    /// const STDERR_ONLY: OutputStr = OutputStr::stderr("foo/bar.stderr");
     /// assert!(STDERR_ONLY.stdout.is_none());
     /// assert_eq!(STDERR_ONLY.stderr.unwrap(), "foo/bar.stderr");
     /// ```
     #[must_use]
     #[inline(always)]
-    pub const fn stderr_only(stderr: StdErr) -> Self {
+    pub const fn stderr(stderr: StdErr) -> Self {
         Self {
             stdout: None,
             stderr: Some(stderr),
@@ -533,17 +533,19 @@ pub trait CommandExt: Sealed {
     /// Tries to run the specified command, and tests that it has the expected stdout and
     /// stderr output.
     ///
-    /// The `check_status` function is used to assert the [`ExitStatus`] of the command. If it
-    /// returns [`false`], this method will panic.
+    /// The `check_status` function is used to assert the [`ExitStatus`] of the command.
+    ///
+    /// This method is intended to be used in a `#[test]` function. It panics if the command output
+    /// mismatches, a system error is encountered, or the `check_status` function returns [`false`].
     ///
     /// [Blessing the output can be requested by setting the `TRYRUN` environment variable to
-    /// `bless`](crate#blessing).
+    /// `bless`.](crate#blessing)
     ///
     /// ## Implementation detail
     /// If the output mismatches, [`git`](https://www.git-scm.com) will be spawned to obtain a
     /// colourful diff.
     ///
-    /// **NOTE:** This detail is subject to change and should not be relied upon.
+    /// **Note:** this detail is subject to change and should not be relied on.
     fn try_run(
         &mut self,
         output: Output!(),
@@ -836,12 +838,12 @@ mod tests {
         cargo_miri.args(&["-q", "--release", "--lib", "--target-dir=target/miri"]);
         if cfg!(release) {
             cargo_miri.run_fail(
-                OutputStr::stderr_only("tests/ui/cargo_miri_release.stderr"),
+                OutputStr::stderr("tests/ui/cargo_miri_release.stderr"),
                 strip_exe(),
             );
         } else {
             cargo_miri.run_pass(
-                OutputStr::stdout_only("tests/ui/cargo_miri_test.stdout"),
+                OutputStr::stdout("tests/ui/cargo_miri_test.stdout"),
                 normalize::noop(),
             );
         }
